pub unsafe extern "C" fn prism_backend_initialize(
backend: *mut PrismBackend,
) -> PrismErrorExpand description
Initializes a backend instance.
Safety
backend must be a live backend that has not been passed to prism_backend_free.
pub unsafe extern "C" fn prism_backend_initialize(
backend: *mut PrismBackend,
) -> PrismErrorInitializes a backend instance.
backend must be a live backend that has not been passed to prism_backend_free.