pub unsafe extern "C" fn prism_backend_pause(
backend: *mut PrismBackend,
) -> PrismErrorExpand description
Pauses currently playing speech.
Safety
backend must be a live backend that has not been passed to prism_backend_free.
pub unsafe extern "C" fn prism_backend_pause(
backend: *mut PrismBackend,
) -> PrismErrorPauses currently playing speech.
backend must be a live backend that has not been passed to prism_backend_free.