pub unsafe extern "C" fn prism_config_init() -> PrismConfigExpand description
Creates a new configuration structure which can be passed to prism_init.
Safety
Safe to call at any time; this is unsafe only because it crosses the FFI boundary.
pub unsafe extern "C" fn prism_config_init() -> PrismConfigCreates a new configuration structure which can be passed to prism_init.
Safe to call at any time; this is unsafe only because it crosses the FFI boundary.