prism_set_log_level

Function prism_set_log_level 

pub unsafe extern "C" fn prism_set_log_level(
    level: PrismLogLevel,
) -> PrismLogLevel
Sets the minimum severity of messages that will be delivered.

Safety

Safe to call at any time; this is unsafe only because it crosses the FFI boundary.