pub unsafe extern "C" fn prism_log_flush()
Blocks until all messages queued before the call have been delivered.
Safe to call at any time; this is unsafe only because it crosses the FFI boundary.
unsafe