prism_set_log_handler

Function prism_set_log_handler 

pub unsafe extern "C" fn prism_set_log_handler(
    handler: PrismLogHandler,
) -> PrismLogHandler
Installs the handler that receives log messages, replacing any previously installed handler.

Safety

handler.fn_, if set, must be safe to call with handler.userdata from prism’s logging thread, and that userdata must outlive the handler.