pub unsafe extern "C" fn prism_version() -> u32
Returns the version of the loaded Prism library as an encoded integer.
Safe to call at any time; this is unsafe only because it crosses the FFI boundary.
unsafe