pub unsafe extern "C" fn prism_version_string() -> *const c_charExpand description
Returns the version of the loaded Prism library as a human-readable string.
Safety
Safe to call at any time; this is unsafe only because it crosses the FFI boundary.